@@ -1,7 +1,7 @@
 /*
-	$Id: dbdimp.h,v 1.44 2005/08/26 01:40:06 turnstep Exp $
+	$Id: dbdimp.h,v 1.49 2006/02/13 03:02:06 turnstep Exp $
 	
-	Copyright (c) 2000-2005 PostgreSQL Global Development Group
+	Copyright (c) 2000-2006 PostgreSQL Global Development Group
 	Portions Copyright (c) 1997-2000 Edmund Mergl
 	Portions Copyright (c) 1994-1997 Tim Bunce
 	
@@ -56,6 +56,7 @@ struct ph_st {
 	STRLEN quotedlen;           /* length of the quoted value */
 	bool   referenced;          /* used for PREPARE AS construction */
 	bool   defaultval;          /* is it using a generic 'default' value? */
+	bool   isdefault;           /* Are we passing a literal 'DEFAULT'? */
 	sql_type_info_t* bind_type; /* type information for this placeholder */
 	struct ph_st *nextph;       /* more linked list goodness */
 };
@@ -75,7 +76,6 @@ struct imp_sth_st {
 
 	STRLEN totalsize;        /* total string length of the statement (with no placeholders)*/
 
-  char   *statement;       /* the rewritten statement, for passing to PQexecP.. */
 	char   *prepare_name;    /* name of the prepared query; NULL if not prepared */
 	char   *firstword;       /* first word of the statement */
 
@@ -91,6 +91,7 @@ struct imp_sth_st {
 	bool   direct;           /* allow bypassing of the statement parsing */
 	bool   is_dml;           /* is this SELECT/INSERT/UPDATE/DELETE? */
 	bool   has_binary;       /* does it have one or more binary placeholders? */
+	bool   has_default;      /* does it have one or more 'DEFAULT' values? */
 };
 
 /* Other (non-static) functions we have added to dbdimp.c */
