@@ -2,14 +2,13 @@
 #ifndef DBDQUOTEH
 #define DBDQUOTEH
 char * null_quote(char *string, STRLEN len, STRLEN *retlen);
-char * quote_varchar(char *string, STRLEN len, STRLEN *retlen);
-char * quote_char(char *string, STRLEN len, STRLEN *retlen);
-char * quote_bytea(unsigned char *string, STRLEN len, STRLEN *retlen);
-char * quote_sql_binary(unsigned char *string, STRLEN len, STRLEN *retlen);
+char * quote_string(char *string, STRLEN len, STRLEN *retlen);
+char * quote_bytea(char *string, STRLEN len, STRLEN *retlen);
+char * quote_sql_binary(char *string, STRLEN len, STRLEN *retlen);
 char * quote_bool(char *string, STRLEN len, STRLEN *retlen);
 char * quote_integer(char *string, STRLEN len, STRLEN *retlen);
 void dequote_char(char *string, STRLEN *retlen);
-void dequote_varchar(char *string, STRLEN *retlen);
+void dequote_string(char *string, STRLEN *retlen);
 void dequote_bytea(char *string, STRLEN *retlen);
 void dequote_sql_binary(char *string, STRLEN *retlen);
 void dequote_bool(char *string, STRLEN *retlen);
